==> alibabacloud_cs20151215-2.4.3.tar.gz: alibabacloud_cs20151215-2.4.3/ChangeLog.md <==
2021-06-09 Version: 2.4.2
- AMP Version.

2021-03-16 Version: 2.4.1
- DescribeClusterNamespaces add response body.

2021-03-12 Version: 2.4.0
- ListTagResources has added the required parameters resource_type and region_id.
- DescribeClusterNodes changes the type of parameter instanceIds to string.
- DescribeClusterAddonsUpgradeStatus set parameters componentIds required .

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-09 Version: 2.2.7
- AMP Version Upgrade.

2021-02-08 Version: 2.2.6
- AMP Version Upgrade.

2021-02-06 Version: 2.2.5
- AMP Version Upgrade.

2021-02-02 Version: 2.2.4
- AMP Version Upgrade.

2021-02-02 Version: 2.2.4
- AMP Version Upgrade.

2021-01-26 Version: 2.2.3
- AMP Version Upgrade.

2020-12-31 Version: 2.2.1
- AMP Version Upgrade.

2020-12-29 Version: 2.2.0
- AMP Version Upgrade.

2020-12-28 Version: 2.1.3
- AMP Version Upgrade.

2020-12-25 Version: 2.1.2
- AMP Version Upgrade.

2020-12-22 Version: 2.1.1
- AMP Version Upgrade.

2020-12-17 Version: 2.1.0
- AMP Version.

2020-12-08 Version: 2.0.6
- AMP Version.

2020-11-20 Version: 2.1.0
- AMP Version.

2020-09-28 Version: 2.0.6
- AMP Version.

2020-09-27 Version: 2.0.4
- AMP Version.

2020-09-27 Version: 2.0.3
- AMP Version.

2020-09-23 Version: 2.0.2
- AMP Version.

2020-09-23 Version: 2.0.1
- AMP Version.

2020-09-23 Version: 2.0.0
- AMP Version.

==> alibabacloud_cs20151215-2.4.4.tar.gz: alibabacloud_cs20151215-2.4.4/ChangeLog.md <==
2021-07-06 Version: 2.4.3
- Fixed an issue with inconsistent size types in the WorkdataDisks in ScaleOutCluster.
- CreateClusterNodePool support public network IP.

2021-06-09 Version: 2.4.2
- AMP Version.

2021-03-16 Version: 2.4.1
- DescribeClusterNamespaces add response body.

2021-03-12 Version: 2.4.0
- ListTagResources has added the required parameters resource_type and region_id.
- DescribeClusterNodes changes the type of parameter instanceIds to string.
- DescribeClusterAddonsUpgradeStatus set parameters componentIds required .

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-22 Version: 2.3.0
- AMP Version Upgrade.

2021-02-09 Version: 2.2.7
- AMP Version Upgrade.

2021-02-08 Version: 2.2.6
- AMP Version Upgrade.

2021-02-06 Version: 2.2.5
- AMP Version Upgrade.

2021-02-02 Version: 2.2.4
- AMP Version Upgrade.

2021-02-02 Version: 2.2.4
- AMP Version Upgrade.

2021-01-26 Version: 2.2.3
- AMP Version Upgrade.

2020-12-31 Version: 2.2.1
- AMP Version Upgrade.

2020-12-29 Version: 2.2.0
- AMP Version Upgrade.

2020-12-28 Version: 2.1.3
- AMP Version Upgrade.

2020-12-25 Version: 2.1.2
- AMP Version Upgrade.

2020-12-22 Version: 2.1.1
- AMP Version Upgrade.

2020-12-17 Version: 2.1.0
- AMP Version.

2020-12-08 Version: 2.0.6
- AMP Version.

2020-11-20 Version: 2.1.0
- AMP Version.

2020-09-28 Version: 2.0.6
- AMP Version.

2020-09-27 Version: 2.0.4
- AMP Version.

2020-09-27 Version: 2.0.3
- AMP Version.

2020-09-23 Version: 2.0.2
- AMP Version.

2020-09-23 Version: 2.0.1
- AMP Version.

2020-09-23 Version: 2.0.0
- AMP Version.
